// +FHDR------------------------------------------------------------
//                 Copyright (c) 2022 SmartLogic.
//                       ALL RIGHTS RESERVED
// -----------------------------------------------------------------
// Filename      : ape_test_entry.c
// Author        : xianfeng.du
// Created On    : 2022-10-19s
// Last Modified :
// -----------------------------------------------------------------
// Description:
//
//
// -FHDR------------------------------------------------------------

#include "typedef.h"
#include "ucp_testcase.h"
#include "ucp_printf.h"
#include "ucp_utility.h"

/*static uint32_t gTestCaseId = 1;
static inline uint32_t get_case_id(void)
{
	return gTestCaseId;
}*/

void ape_test_task_reg(void)
{
#if 0
	uint32_t caseId = get_case_id();
	switch (caseId) {
		case 1:
			ape_test_case1();
			break;
		case 2:
			//ape_test_case2();
			break;
		default:
			break;
	}
#endif
    uint32_t apeId = get_core_id();
    if (0 == apeId) {
        ape0_test_task_reg();
    }
    else if (1 == apeId)
    {
        ape1_test_task_reg();
    }
    else if (2 == apeId)
    {
        ape2_test_task_reg();
    }
    else if (3 == apeId)
    {
        ape3_test_task_reg();
    }
    else if (4 == apeId)
    {
        ape4_test_task_reg();
    }
    else if (5 == apeId)
    {
        ape5_test_task_reg();
    }
    else if (6 == apeId)
    {
        ape6_test_task_reg();
    }
    else if (7 == apeId)
    {
        ape7_test_task_reg();
    }
    else
    {
    }
    UCP_PRINT_DEBUG("ape[0x%x]_test_task_reg start", apeId);

	return;
}

